spoon.messaging.decorators

Package spoon :: Package messaging :: Module decorators |
[show private | hide private]
[frames | no frames]

## Module spoon.messaging.decorators

Classes
`handleMsg` | The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
`receive` | The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net